@@ -8,7 +8,12 @@ use File::Spec::Functions qw(splitdir catdir);
 use Carp qw(croak);
 
 
-$VERSION = '0.6';
+# ObQuote:
+# Bob Porter: Looks like you've been missing a lot of work lately. 
+# Peter Gibbons: I wouldn't say I've been missing it, Bob! 
+
+
+$VERSION = '0.8';
 
 =pod
 
@@ -56,7 +61,7 @@ Or if you want to look in another directory
 Or if you want to instantiate each plugin rather than just return the name
 
     package MyClass;
-    use Module::Pluggable (instantiate => 1);
+    use Module::Pluggable (instantiate => 'new');
     use base qw(Module::Pluggable);
 
 and then
@@ -104,16 +109,29 @@ See the test files for examples on how to do this.
 But something like this should work
 
 
-	BEGIN {  use File::Spec::Functions qw(catdir) }
-	# search in Some/Path/To/Plugins but in a cross platform way
-	use Module::Pluggable (search_path => [catdir(qw(Some Path To Plugins))]);
+    use File::Spec::Functions qw(catdir);
+    # search in Some/Path/To/Plugins but in a cross platform way
+    use Module::Pluggable (search_path => [catdir(qw(Some Path To Plugins))]);
 
 
 
 =head2 instantiate
 
-If this is set to true then the class will be 
-instantiated with whatever arguments are passed to 'plugins'
+Call this method on the class. In general this will probably be 'new'
+but it can be whatever you want. Whatever arguments are passed to 'plugins' 
+will be passed to the method.
+
+The default is 'undef' i.e just return the class name.
+    
+
+=head1 FUTURE PLANS
+
+This does everything I need and I can't really think fo any other 
+features I want to add. Finding multiple packages in one .pm file
+is probably too hard and AFAICS it should 'just work'[tm] with 
+PAR.
+
+However suggestions (and patches) are welcome.
 
 =head1 AUTHOR
 
@@ -121,19 +139,17 @@ Simon Wistow <simon@thegestalt.org>
 
 =head1 COPYING
 
-(c)opyright 2002, Simon Wistow
+Copyright, 2003 Simon Wistow
 
 Distributed under the same terms as Perl itself.
 
-This software is under no warranty and will probably ruin your life, kill your friends, burn your house and bring about the apocalypse
-
 =head1 BUGS
 
 None known.
 
 =head1 SEE ALSO
 
-L<File::Spec>, L<File::Find::Rule>, L<File::Basename>
+L<File::Spec>, L<File::Find::Rule>, L<File::Basename>, L<Class::Factory::Util>
 
 =cut 
 
@@ -142,69 +158,73 @@ sub import {
     my $class   = shift;
     our %opts   = @_;
 
-	# the default name for the method is 'plugins'
+    # the default name for the method is 'plugins'
     my $sub = $opts{'sub_name'} || 'plugins';
 
-	# have to turn off refs which makes me feel dirty but hey ho
+    # get our package 
+    my ($pkg) = caller;
+
+    # have to turn off refs which makes me feel dirty but hey ho
     no strict 'refs';
-	# export the subroutine
-    *$sub = sub {
+    # export the subroutine
+    *{"$pkg\::$sub"} = sub {
         my $self = shift;
 
-		# default search path is '<Module>/<Name>/Plugin'
-		# we use catdir to amke it cross platform
+        # default search path is '<Module>/<Name>/Plugin'
+        # we use catdir to amke it cross platform
         my $packparts = catdir((split /::/, ref $self), 'Plugin');    
 
-		# they have to take care of the corss platform stuff themselves
+        # they have to take care of the corss platform stuff themselves
         $opts{'search_path'} = [$packparts] unless $opts{'search_path'}; 
 
-		# predeclare
+        # predeclare
         my @plugins;
 
-		# go through our @INC
+        # go through our @INC
         foreach my $dir (@INC) {
 
-			# and each directory in our search path
+            # and each directory in our search path
             foreach my $searchpath (@{$opts{'search_path'}}) {
-				# create the search directory in a corss platform goodness way
+                # create the search directory in a corss platform goodness way
                 my $sp = catdir($dir, $searchpath);
-				# if it doesn't exist or it's not a dir then skip it
+                # if it doesn't exist or it's not a dir then skip it
                 next unless ( -e $sp && -d $sp );
                 
-				# find all the .pm files in it
-				# this isn't perfect and won't find multiple plugins per file
+                # find all the .pm files in it
+                # this isn't perfect and won't find multiple plugins per file
                 my @files = find( name => "*.pm", in => [$sp] );
 
-				# foreach one we've found 
+                # foreach one we've found 
                 foreach my $file (@files) {
-					# parse the file to get the name
+                    # parse the file to get the name
                     my ($name) = fileparse($file, qr{\.pm});
-					# then create the class name in a cross platform way
+                    # then create the class name in a cross platform way
                     push @plugins, join "::", splitdir catdir($searchpath,$name);
                 }
 
             }
         }
 
-		# return blank unless we've found anything
-		return () unless @plugins;
+        # return blank unless we've found anything
+        return () unless @plugins;
 
-		# remove duplicates
-		# probably not necessary but hey ho
+        # remove duplicates
+        # probably not necessary but hey ho
         my %plugins = map { $_ => 1 } @plugins;
 
-		# are we instantiating?
-        if ($opts{'instantiate'}) {
+        # are we instantiating?
+        if (defined $opts{'instantiate'}) {
+            my $method = $opts{'instantiate'};
             return map {
-							# use string based eval to force bareword require
+                            # use string based eval to force bareword require
                             eval "require $_"; 
-							# and die it we can't do that 
+                            # and die it we can't do that 
                             croak "Couldn't instantiate $_" if $@;
-							# instantiate with the options passed into the sub
-                            $_->new(@_); 
+                            # instantiate with the options passed into the sub
+                            $_->$method(@_); 
                         } sort keys %plugins;
         } else { 
-			# no? just return the names
+            # no? just return the names
             return sort keys %plugins;
         }
 
